@@ -14,7 +14,7 @@ import qibuild.parsers
 
 def configure_parser(parser):
     """Configure parser for this action"""
-    qibuild.parsers.build_parser(parser)
+    qibuild.parsers.cmake_build_parser(parser)
     qibuild.parsers.project_parser(parser)
     parser.add_argument("--cflags",
                         help="Outputs required compiler flags")
